@@ -49,14 +49,14 @@ function () {
 
 ref.data <- function() {
   # Reference profile used throughout the tests. 
-  ref = list( D3   = c("14,16", "16,16", "15,17"),
+  ref = list( D3S1358   = c("14,16", "16,16", "15,17"),
               vWA  = c("15,19", "15,16", "16,19"),
-              D16  = c("11,14", "13,13", "12,13"),
-              D2   = c("24,25", "20,20", "18,25"),
-              D8   = c("12,13", "11,15", "11,13"),
-              D21  = c("28,31", "29,30", "29,30"),
-              D18  = c("14,17", "17,17", "15,17"),
-              D19  = c("15.2,17.2", "12,14", "14,14"),
+              D16S539  = c("11,14", "13,13", "12,13"),
+              D2S1338   = c("24,25", "20,20", "18,25"),
+              D8S1179   = c("12,13", "11,15", "11,13"),
+              D21S11  = c("28,31", "29,30", "29,30"),
+              D18S51  = c("14,17", "17,17", "15,17"),
+              D19S433  = c("15.2,17.2", "12,14", "14,14"),
               TH01 = c("9,9.3", "6,8", "6,7"),
               FGA  = c("22,23", "22,25", "20,22") )
   ref = data.frame( ref, row.names=c('Suspect', 'Victim 1', 'Victim 2'),
@@ -66,28 +66,40 @@ ref.data <- function() {
 
 ethnic.database.data <- function() {
   # Creates ethnic frequency data for tests.
-  d3 = c( 1, 5, 115, 232, 216, 170, 123, 12, # first column
-          -93.9413043478, -89.9413043478, -85.9413043478, -81.9413043478,
-          -77.9413043478, -73.9413043478, -69.9413043478, -65.9413043478 )
+  d3 = c(1.000000000000,   4.000000000000,   1.000000000000,  10.000000000000,
+321.000000000000, 670.000000000000, 614.000000000000, 522.000000000000,
+373.000000000000,  29.000000000000,   5.000000000000, -76.908455882353,
+-72.908455882353, -68.908455882353, -64.908455882353, -60.908455882353,
+-56.908455882353, -52.908455882353, -48.908455882353, -44.908455882353,
+-40.908455882353, -36.908455882353)
   d3 = matrix(d3, , 2)
-  row.names(d3) <- c("12", "13", "14", "15", "16", "17", "18", "19")
-  d18 = c( 12, 5, 138, 113, 155, 1, 124, 107, 90, 69, 36, 15, 7, 2, # first column
-           70.0586956522, 74.0586956522, 78.0586956522, 82.0586956522,
-           86.0586956522, 88.0586956522, 90.0586956522, 94.0586956522,
-           98.0586956522, 102.0586956522, 106.0586956522, 110.0586956522,
-           114.0586956522, 118.0587 )
+  row.names(d3) <- c("10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20")
+  d18 = c(1.000000000000,   3.000000000000,  29.000000000000,  35.000000000000,
+381.000000000000, 299.000000000000, 410.000000000000, 380.000000000000,
+332.000000000000, 286.000000000000, 197.000000000000, 118.000000000000,
+45.000000000000,  22.000000000000,   6.000000000000,   3.000000000000,
+3.000000000000,  62.091544117647,  66.091544117647,  70.091544117647,
+74.091544117647,  78.091544117647,  82.091544117647,  86.091544117647,
+90.091544117647,  94.091544117647,  98.091544117647, 102.091544117647,
+106.091544117647, 110.091544117647, 114.091544117647, 118.091544117647,
+122.091544117647, 126.091544117647)
   d18 = matrix(d18, , 2)
-  row.names(d18) <- c("10", "11", "12", "13", "14", "14.2", "15", "16", "17",
-                      "18", "19", "20", "21", "22")
-  d19 = c( 76, 194, 11, 334, 13, 155, 33, 36, 15, 4, 2, 1,
-           -90.9413043478, -86.9413043478, -84.9413043478, -82.9413043478, -80.9413043478,
-           -78.9413043478, -76.9413043478, -74.9413043478, -72.9413043478, -70.9413043478,
-           -64.9413043478, -60.9413043478 ) 
+  row.names(d18) <- c("8",  "9",  "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22",
+ "23", "24")
+  d19 = c(1.000000000000,   9.000000000000, 200.000000000000,   2.000000000000,
+4.000000000000, 590.000000000000,  36.000000000000, 923.000000000000,
+51.000000000000, 456.000000000000, 103.000000000000, 111.000000000000,
+38.000000000000,  14.000000000000,   9.000000000000,   1.000000000000,
+2.000000000000, -72.908455882353, -68.908455882353, -64.908455882353,
+-63.908455882353, -62.908455882353, -60.908455882353, -58.908455882353,
+-56.908455882353, -54.908455882353, -52.908455882353, -50.908455882353,
+-48.908455882353, -46.908455882353, -44.908455882353, -42.908455882353,
+-40.908455882353, -38.908455882353) 
   d19 = matrix(d19, , 2)
-  row.names(d19) <- c("12", "13", "13.2", "14", "14.2", "15", "15.2", "16",
-                      "16.2", "17", "18.2", "19.2")
+  row.names(d19) <- c( "10",   "11",   "12",   "12.1", "12.2", "13",   "13.2", "14",   "14.2", "15",  
+ "15.2", "16",   "16.2", "17",   "17.2", "18",   "18.2")
 
-  return(list(D3=d3, D18=d18, D19=d19))
+  return(list(D3S1358=d3, D18S51=d18, D19S433=d19))
 }
 
 internal.representation.data = function() {
@@ -95,21 +107,21 @@ internal.representation.data = function() {
   # 
   # Used for testing both the construction of the internal representation and
   # the pack.genetic.input test.
-  result = list( D3=  list( list(csp=c("14", "16"), unc=""),
+  result = list( D3S1358=  list( list(csp=c("14", "16"), unc=""),
                             list(csp=c("14", "16"), unc="") ),
                  vWA= list( list(csp=c("15", "16", "19"), unc=""),
                             list(csp=c("15", "16", "17", "19"), unc="") ),
-                 D16= list( list(csp=c("11", "13", "14"), unc=""),
+                 D16S539= list( list(csp=c("11", "13", "14"), unc=""),
                             list(csp=c("11", "13", "14"), unc="") ),
-                 D2=  list( list(csp=c("20", "23", "24", "25"), unc=""),
+                 D2S1338=  list( list(csp=c("20", "23", "24", "25"), unc=""),
                             list(csp=c("20", "24", "25"), unc="") ),
-                 D8=  list( list(csp=c("11", "12", "13", "15"), unc=""),
+                 D8S1179=  list( list(csp=c("11", "12", "13", "15"), unc=""),
                             list(csp=c("11", "12", "13", "15"), unc="") ),
-                 D21= list( list(csp=c("28", "31"), unc=""),
+                 D21S11= list( list(csp=c("28", "31"), unc=""),
                             list(csp=c("28", "29", "30", "31", "31.2"), unc="") ),
-                 D18= list( list(csp=c(""), unc=""),
+                 D18S51= list( list(csp=c(""), unc=""),
                             list(csp=c("13", "14", "16", "17"), unc="") ),
-                 D19= list( list(csp=c("12", "13", "15.2", "17.2"), unc=""),
+                 D19S433= list( list(csp=c("12", "13", "15.2", "17.2"), unc=""),
                             list(csp=c("12", "13", "14", "15.2", "17.2"), unc="") ),
                  TH01=list( list(csp=c("6", "8", "9", "9.3"), unc=""),
                             list(csp=c("6", "8", "9", "9.3"), unc="") ),
@@ -120,14 +132,14 @@ internal.representation.data = function() {
 
 known.alleles.data <- function() {
   # Result from known allele call. 
-  check <- list( D3   = c("14", "16", "16", "16", "15", "17"), 
+  check <- list( D3S1358   = c("14", "16", "16", "16", "15", "17"), 
                  vWA  = c("15", "19", "15", "16", "16", "19"), 
-                 D16  = c("11", "14", "13", "13", "12", "13"), 
-                 D2   = c("24", "25", "20", "20", "18", "25"), 
-                 D8   = c("12", "13", "11", "15", "11", "13"), 
-                 D21  = c("28", "31", "29", "30", "29", "30"), 
-                 D18  = c("14", "17", "17", "17", "15", "17"), 
-                 D19  = c("15.2", "17.2", "12", "14", "14", "14"), 
+                 D16S539  = c("11", "14", "13", "13", "12", "13"), 
+                 D2S1338   = c("24", "25", "20", "20", "18", "25"), 
+                 D8S1179   = c("12", "13", "11", "15", "11", "13"), 
+                 D21S11  = c("28", "31", "29", "30", "29", "30"), 
+                 D18S51  = c("14", "17", "17", "17", "15", "17"), 
+                 D19S433  = c("15.2", "17.2", "12", "14", "14", "14"), 
                  TH01 = c("9", "9.3", "6", "8", "6", "7"), 
                  FGA  = c("22", "23", "22", "25", "20", "22") )
   return(data.frame(check, stringsAsFactors=FALSE))
@@ -140,12 +152,12 @@ test_ethnic.database <- svTest(function() {
   # Test ethnic frequency function
   if(! "ethnic.database" %in% ls(.GlobalEnv))
     ethnic.database = getFromNamespace("ethnic.database", "likeLTD")
-  result = ethnic.database('EA1')
+  result = ethnic.database('NDU1')
 
   check <- ethnic.database.data()
-  checkEquals(result$D3, check$D3)
-  checkEquals(result$D18, check$D18)
-  checkEquals(result$D19, check$D19)
+  checkEquals(result$D3S1358, check$D3S1358)
+  checkEquals(result$D18S51, check$D18S51)
+  checkEquals(result$D19S433, check$D19S433)
 })
 
 
